@@ -7,6 +7,7 @@ use Icinga\Test\BaseTestCase;
 use Icinga\Application\Config;
 use Icinga\Forms\Config\UserBackendConfigForm;
 use Icinga\Forms\Config\UserBackendReorderForm;
+use Icinga\Application\Icinga;
 
 class UserBackendConfigFormWithoutSave extends UserBackendConfigForm
 {
@@ -41,6 +42,7 @@ class AuthenticationBackendReorderFormTest extends BaseTestCase
             )
         );
 
+        Icinga::app()->shouldReceive('getModuleManager->getLoadedModules')->andReturn([]);
         $this->getRequestMock()->shouldReceive('getMethod')->andReturn('POST')
             ->shouldReceive('isPost')->andReturn(true)
             ->shouldReceive('getPost')->andReturn(array('backend_newpos' => 'test3|1'));
